==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_entities/assetequipment_001/ChildAsset.java <==

package net.datastream.schemas.mp_entities.assetequipment_001;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.DEPARTMENTID_Type;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.TYPE_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ASSETID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TYPE"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}COSTROLLUP"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}DEPENDENTON"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}OUTOFSERVICE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_entities/AssetEquipment_001}ChildAsset" maxOccurs="unbounded" minOccurs="0"/>
 *       </sequence>
 *       <attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "assetid",
    "type",
    "costrollup",
    "dependenton",
    "departmentid",
    "outofservice",
    "childAsset"
})
@XmlRootElement(name = "ChildAsset")
public class ChildAsset {

    @XmlElement(name = "ASSETID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected EQUIPMENTID_Type assetid;
    @XmlElement(name = "TYPE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected TYPE_Type type;
    @XmlElement(name = "COSTROLLUP", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String costrollup;
    @XmlElement(name = "DEPENDENTON", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String dependenton;
    @XmlElement(name = "DEPARTMENTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected DEPARTMENTID_Type departmentid;
    @XmlElement(name = "OUTOFSERVICE", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String outofservice;
    @XmlElement(name = "ChildAsset")
    protected List<ChildAsset> childAsset;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Gets the value of the assetid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getASSETID() {
        return assetid;
    }

    /**
     * Sets the value of the assetid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setASSETID(EQUIPMENTID_Type value) {
        this.assetid = value;
    }

    /**
     * Gets the value of the type property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getTYPE() {
        return type;
    }

    /**
     * Sets the value of the type property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setTYPE(TYPE_Type value) {
        this.type = value;
    }

    /**
     * Gets the value of the costrollup property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOSTROLLUP() {
        return costrollup;
    }

    /**
     * Sets the value of the costrollup property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOSTROLLUP(String value) {
        this.costrollup = value;
    }

    /**
     * Gets the value of the dependenton property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDEPENDENTON() {
        return dependenton;
    }

    /**
     * Sets the value of the dependenton property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDEPENDENTON(String value) {
        this.dependenton = value;
    }

    /**
     * Gets the value of the departmentid property.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Sets the value of the departmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

    /**
     * Gets the value of the outofservice property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOUTOFSERVICE() {
        return outofservice;
    }

    /**
     * Sets the value of the outofservice property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOUTOFSERVICE(String value) {
        this.outofservice = value;
    }

    /**
     * Gets the value of the childAsset property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the Jakarta XML Binding object.
     * This is why there is not a {@code set} method for the childAsset property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getChildAsset().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ChildAsset }
     * 
     * 
     * @return
     *     The value of the childAsset property.
     */
    public List<ChildAsset> getChildAsset() {
        if (childAsset == null) {
            childAsset = new ArrayList<>();
        }
        return this.childAsset;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}

==> eam-wshub-proxyclient-12.2-8-sources.jar: net/datastream/schemas/mp_entities/assetequipment_001/ChildAsset.java <==

package net.datastream.schemas.mp_entities.assetequipment_001;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.DEPARTMENTID_Type;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.TYPE_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSETID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COSTROLLUP"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPENDENTON"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OUTOFSERVICE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/AssetEquipment_001}ChildAsset" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "assetid",
    "type",
    "costrollup",
    "dependenton",
    "departmentid",
    "outofservice",
    "childAsset"
})
@XmlRootElement(name = "ChildAsset")
public class ChildAsset {

    @XmlElement(name = "ASSETID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected EQUIPMENTID_Type assetid;
    @XmlElement(name = "TYPE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected TYPE_Type type;
    @XmlElement(name = "COSTROLLUP", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String costrollup;
    @XmlElement(name = "DEPENDENTON", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String dependenton;
    @XmlElement(name = "DEPARTMENTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected DEPARTMENTID_Type departmentid;
    @XmlElement(name = "OUTOFSERVICE", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String outofservice;
    @XmlElement(name = "ChildAsset")
    protected List<ChildAsset> childAsset;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Gets the value of the assetid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getASSETID() {
        return assetid;
    }

    /**
     * Sets the value of the assetid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setASSETID(EQUIPMENTID_Type value) {
        this.assetid = value;
    }

    /**
     * Gets the value of the type property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getTYPE() {
        return type;
    }

    /**
     * Sets the value of the type property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setTYPE(TYPE_Type value) {
        this.type = value;
    }

    /**
     * Gets the value of the costrollup property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOSTROLLUP() {
        return costrollup;
    }

    /**
     * Sets the value of the costrollup property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOSTROLLUP(String value) {
        this.costrollup = value;
    }

    /**
     * Gets the value of the dependenton property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDEPENDENTON() {
        return dependenton;
    }

    /**
     * Sets the value of the dependenton property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDEPENDENTON(String value) {
        this.dependenton = value;
    }

    /**
     * Gets the value of the departmentid property.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Sets the value of the departmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

    /**
     * Gets the value of the outofservice property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOUTOFSERVICE() {
        return outofservice;
    }

    /**
     * Sets the value of the outofservice property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOUTOFSERVICE(String value) {
        this.outofservice = value;
    }

    /**
     * Gets the value of the childAsset property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the childAsset property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getChildAsset().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ChildAsset }
     * 
     * 
     */
    public List<ChildAsset> getChildAsset() {
        if (childAsset == null) {
            childAsset = new ArrayList<ChildAsset>();
        }
        return this.childAsset;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}
